@@ -21,8 +21,9 @@ async def simulation(subtensor):
         subtensor,
     )
 
-    async with controller:
-        yield controller
+    yield controller
+    # async with controller:
+    #     yield controller
 
 
 
